@@ -6,13 +6,24 @@ from functools import wraps
 import numpy as np
 from numpy.compat import basestring
 
-from .core import blockwise, asarray
-from . import chunk
+from .core import blockwise, asarray, einsum_lookup
 
 einsum_symbols = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
 einsum_symbols_set = set(einsum_symbols)
 
 
+def chunk_einsum(*operands, **kwargs):
+    subscripts = kwargs.pop('subscripts')
+    ncontract_inds = kwargs.pop('ncontract_inds')
+    dtype = kwargs.pop('kernel_dtype')
+    einsum = einsum_lookup.dispatch(type(operands[0]))
+    chunk = einsum(subscripts, *operands, dtype=dtype, **kwargs)
+
+    # Avoid concatenate=True in blockwise by adding 1's
+    # for the contracted dimensions
+    return chunk.reshape(chunk.shape + (1,) * ncontract_inds)
+
+
 # This function duplicates numpy's _parse_einsum_input() function
 # See https://github.com/numpy/numpy/blob/master/LICENSE.txt
 # or NUMPY_LICENSE.txt within this directory
@@ -230,7 +241,7 @@ def einsum(*operands, **kwargs):
 
     # Introduce the contracted indices into the blockwise product
     # so that we get numpy arrays, not lists
-    result = blockwise(chunk.einsum, tuple(outputs) + tuple(contract_inds),
+    result = blockwise(chunk_einsum, tuple(outputs) + tuple(contract_inds),
                        *(a for ap in zip(ops, inputs) for a in ap),
                        # blockwise parameters
                        adjust_chunks={ind: 1 for ind in contract_inds}, dtype=dtype,
