@@ -20,7 +20,7 @@ from ..utils import import_required, is_integer, parse_bytes
 
 
 def read_bytes(urlpath, delimiter=None, not_zero=False, blocksize="128 MiB",
-               sample=True, compression=None, include_path=False, **kwargs):
+               sample='10 kiB', compression=None, include_path=False, **kwargs):
     """Given a path or paths, return delayed objects that read from those paths.
 
     The path may be a filename like ``'2015-01-01.csv'`` or a globstring
@@ -48,9 +48,10 @@ def read_bytes(urlpath, delimiter=None, not_zero=False, blocksize="128 MiB",
         Chunk size in bytes, defaults to "128 MiB"
     compression : string or None
         String like 'gzip' or 'xz'.  Must support efficient random access.
-    sample : bool or int
-        Whether or not to return a header sample. If an integer is given it is
-        used as sample size, otherwise the default sample size is 10kB.
+    sample : int or string
+        Whether or not to return a header sample.
+        Values can be ``False`` for "no sample requested"
+        Or an integer or string value like ``2**20`` or ``"1 MiB"``
     include_path : bool
         Whether or not to include the path with the bytes representing a particular file.
         Default is False.
@@ -123,9 +124,12 @@ def read_bytes(urlpath, delimiter=None, not_zero=False, blocksize="128 MiB",
         out.append(values)
 
     if sample:
+        if sample is True:
+            sample = '10 kiB'  # backwards compatibility
+        if isinstance(sample, str):
+            sample = parse_bytes(sample)
         with OpenFile(fs, paths[0], compression=compression) as f:
-            nbytes = 10000 if sample is True else sample
-            sample = read_block(f, 0, nbytes, delimiter)
+            sample = read_block(f, 0, sample, delimiter)
     if include_path:
         return sample, out, paths
     return sample, out
