@@ -1,9 +1,12 @@
 from __future__ import print_function, division, absolute_import
 
+import io
 import sys
+import os
 from contextlib import contextmanager
 
 import pytest
+import numpy as np
 
 s3fs = pytest.importorskip('s3fs')
 boto3 = pytest.importorskip('boto3')
@@ -12,13 +15,13 @@ httpretty = pytest.importorskip('httpretty')
 
 from toolz import concat, valmap, partial
 
-from dask import compute, get
+from dask import compute
 from dask.bytes.s3 import DaskS3FileSystem
 from dask.bytes.core import read_bytes, open_files, get_pyarrow_filesystem
 from dask.bytes.compression import compress, files as compress_files, seekable_files
 
 
-compute = partial(compute, get=get)
+compute = partial(compute, scheduler='sync')
 
 
 test_bucket_name = 'test'
@@ -32,43 +35,142 @@ files = {'test/accounts.1.json':  (b'{"amount": 100, "name": "Alice"}\n'
                                    b'{"amount": 800, "name": "Dennis"}\n')}
 
 
-@pytest.yield_fixture
-def s3():
-    # writable local S3 system
-    import moto
+@contextmanager
+def ensure_safe_environment_variables():
+    """
+    Get a context manager to safely set environment variables
+    All changes will be undone on close, hence environment variables set
+    within this contextmanager will neither persist nor change global state.
+    """
+    saved_environ = dict(os.environ)
     try:
+        yield
+    finally:
+        os.environ.clear()
+        os.environ.update(saved_environ)
+
+
+@pytest.fixture()
+def s3():
+    with ensure_safe_environment_variables():
+        # temporary workaround as moto fails for botocore >= 1.11 otherwise,
+        # see https://github.com/spulec/moto/issues/1924 & 1952
+        os.environ.setdefault("AWS_ACCESS_KEY_ID", "foobar_key")
+        os.environ.setdefault("AWS_SECRET_ACCESS_KEY", "foobar_secret")
+
+        # writable local S3 system
+        import moto
         with moto.mock_s3():
             client = boto3.client('s3')
             client.create_bucket(Bucket=test_bucket_name, ACL='public-read-write')
             for f, data in files.items():
                 client.put_object(Bucket=test_bucket_name, Key=f, Body=data)
             yield s3fs.S3FileSystem(anon=True)
-    finally:
-        httpretty.HTTPretty.disable()
-        httpretty.HTTPretty.reset()
+
+            httpretty.HTTPretty.disable()
+            httpretty.HTTPretty.reset()
 
 
 @contextmanager
 def s3_context(bucket, files):
-    m = moto.mock_s3()
-    m.start()
+    with ensure_safe_environment_variables():
+        # temporary workaround as moto fails for botocore >= 1.11 otherwise,
+        # see https://github.com/spulec/moto/issues/1924 & 1952
+        os.environ.setdefault("AWS_ACCESS_KEY_ID", "foobar_key")
+        os.environ.setdefault("AWS_SECRET_ACCESS_KEY", "foobar_secret")
+
+        with moto.mock_s3():
+            client = boto3.client('s3')
+            client.create_bucket(Bucket=bucket, ACL='public-read-write')
+            for f, data in files.items():
+                client.put_object(Bucket=bucket, Key=f, Body=data)
+
+            yield DaskS3FileSystem(anon=True)
+
+            for f, data in files.items():
+                try:
+                    client.delete_object(Bucket=bucket, Key=f, Body=data)
+                except Exception:
+                    pass
+                finally:
+                    httpretty.HTTPretty.disable()
+                    httpretty.HTTPretty.reset()
+
+
+@pytest.fixture()
+@pytest.mark.slow
+def s3_with_yellow_tripdata(s3):
+    """
+    Fixture with sample yellowtrip CSVs loaded into S3.
+
+    Provides the following CSVs:
+
+    * s3://test/nyc-taxi/2015/yellow_tripdata_2015-01.csv
+    * s3://test/nyc-taxi/2014/yellow_tripdata_2015-mm.csv
+      for mm from 01 - 12.
+    """
+    pd = pytest.importorskip('pandas')
+
+    data = {'VendorID': {0: 2, 1: 1, 2: 1, 3: 1, 4: 1},
+            'tpep_pickup_datetime': {0: '2015-01-15 19:05:39',
+                                     1: '2015-01-10 20:33:38',
+                                     2: '2015-01-10 20:33:38',
+                                     3: '2015-01-10 20:33:39',
+                                     4: '2015-01-10 20:33:39'},
+            'tpep_dropoff_datetime': {0: '2015-01-15 19:23:42',
+                                      1: '2015-01-10 20:53:28',
+                                      2: '2015-01-10 20:43:41',
+                                      3: '2015-01-10 20:35:31',
+                                      4: '2015-01-10 20:52:58'},
+            'passenger_count': {0: 1, 1: 1, 2: 1, 3: 1, 4: 1},
+            'trip_distance': {0: 1.59, 1: 3.3, 2: 1.8, 3: 0.5, 4: 3.0},
+            'pickup_longitude': {0: -73.993896484375,
+                                 1: -74.00164794921875,
+                                 2: -73.96334075927734,
+                                 3: -74.00908660888672,
+                                 4: -73.97117614746094},
+            'pickup_latitude': {0: 40.7501106262207,
+                                1: 40.7242431640625,
+                                2: 40.80278778076172,
+                                3: 40.71381759643555,
+                                4: 40.762428283691406},
+            'RateCodeID': {0: 1, 1: 1, 2: 1, 3: 1, 4: 1},
+            'store_and_fwd_flag': {0: 'N', 1: 'N', 2: 'N', 3: 'N', 4: 'N'},
+            'dropoff_longitude': {0: -73.97478485107422,
+                                  1: -73.99441528320312,
+                                  2: -73.95182037353516,
+                                  3: -74.00432586669923,
+                                  4: -74.00418090820312},
+            'dropoff_latitude': {0: 40.75061798095703,
+                                 1: 40.75910949707031,
+                                 2: 40.82441329956055,
+                                 3: 40.71998596191406,
+                                 4: 40.742652893066406},
+            'payment_type': {0: 1, 1: 1, 2: 2, 3: 2, 4: 2},
+            'fare_amount': {0: 12.0, 1: 14.5, 2: 9.5, 3: 3.5, 4: 15.0},
+            'extra': {0: 1.0, 1: 0.5, 2: 0.5, 3: 0.5, 4: 0.5},
+            'mta_tax': {0: 0.5, 1: 0.5, 2: 0.5, 3: 0.5, 4: 0.5},
+            'tip_amount': {0: 3.25, 1: 2.0, 2: 0.0, 3: 0.0, 4: 0.0},
+            'tolls_amount': {0: 0.0, 1: 0.0, 2: 0.0, 3: 0.0, 4: 0.0},
+            'improvement_surcharge': {0: 0.3, 1: 0.3, 2: 0.3, 3: 0.3, 4: 0.3},
+            'total_amount': {0: 17.05, 1: 17.8, 2: 10.8, 3: 4.8, 4: 16.3}}
+    sample = pd.DataFrame(data)
+    df = sample.take(np.arange(5).repeat(10000))
+    file = io.BytesIO()
+    sfile = io.TextIOWrapper(file)
+    df.to_csv(sfile, index=False)
+
+    key = "nyc-taxi/2015/yellow_tripdata_2015-01.csv"
     client = boto3.client('s3')
-    client.create_bucket(Bucket=bucket, ACL='public-read-write')
-    for f, data in files.items():
-        client.put_object(Bucket=bucket, Key=f, Body=data)
+    client.put_object(Bucket=test_bucket_name, Key=key, Body=file)
+    key = "nyc-taxi/2014/yellow_tripdata_2014-{:0>2d}.csv"
 
-    yield DaskS3FileSystem(anon=True)
-
-    for f, data in files.items():
-        try:
-            client.delete_object(Bucket=bucket, Key=f, Body=data)
-        except Exception:
-            pass
-        finally:
-            m.stop()
-            httpretty = pytest.importorskip('httpretty')
-            httpretty.HTTPretty.disable()
-            httpretty.HTTPretty.reset()
+    for i in range(1, 13):
+        file.seek(0)
+        client.put_object(Bucket=test_bucket_name,
+                          Key=key.format(i),
+                          Body=file)
+    yield
 
 
 def test_get_s3():
@@ -135,14 +237,15 @@ def test_read_bytes_blocksize_none(s3):
     assert sum(map(len, values)) == len(files)
 
 
-@pytest.mark.slow
-@pytest.mark.network
-def test_read_bytes_blocksize_on_large_data():
-    _, L = read_bytes('s3://dask-data/nyc-taxi/2015/yellow_tripdata_2015-01.csv',
-                      blocksize=None, anon=True)
+def test_read_bytes_blocksize_on_large_data(s3_with_yellow_tripdata):
+    _, L = read_bytes(
+        's3://{}/nyc-taxi/2015/yellow_tripdata_2015-01.csv'.format(
+            test_bucket_name),
+        blocksize=None, anon=True)
     assert len(L) == 1
 
-    _, L = read_bytes('s3://dask-data/nyc-taxi/2014/*.csv', blocksize=None, anon=True)
+    _, L = read_bytes('s3://{}/nyc-taxi/2014/*.csv'.format(test_bucket_name),
+                      blocksize=None, anon=True)
     assert len(L) == 12
 
 
@@ -244,7 +347,7 @@ def test_read_text_passes_through_options():
     db = pytest.importorskip('dask.bag')
     with s3_context('csv', {'a.csv': b'a,b\n1,2\n3,4'}) as s3:
         df = db.read_text('s3://csv/*.csv', storage_options={'s3': s3})
-        assert df.count().compute(get=get) == 3
+        assert df.count().compute(scheduler='sync') == 3
 
 
 @pytest.mark.parametrize("engine", ['pyarrow', 'fastparquet'])
