@@ -3,6 +3,9 @@ from __future__ import absolute_import, division, print_function
 
 from ..optimization import cull, fuse_getitem, fuse
 from .. import config, core
+from ..highlevelgraph import HighLevelGraph
+from ..utils import ensure_dict
+from ..blockwise import optimize_blockwise
 
 try:
     import fastparquet  # noqa: F401
@@ -11,6 +14,11 @@ except ImportError:
 
 
 def optimize(dsk, keys, **kwargs):
+
+    if isinstance(dsk, HighLevelGraph):
+        dsk = optimize_blockwise(dsk, keys=list(core.flatten(keys)))
+
+    dsk = ensure_dict(dsk)
     from .io import dataframe_from_ctable
     if isinstance(keys, list):
         dsk, dependencies = cull(dsk, list(core.flatten(keys)))
