@@ -3,6 +3,7 @@ from __future__ import absolute_import, division, print_function
 import math
 from operator import getitem
 import uuid
+import warnings
 
 import numpy as np
 import pandas as pd
@@ -211,8 +212,10 @@ def shuffle(df, index, shuffle=None, npartitions=None, max_branch=32,
 
     partitions = index.map_partitions(partitioning_index,
                                       npartitions=npartitions or df.npartitions,
-                                      meta=pd.Series([0]))
+                                      meta=pd.Series([0]),
+                                      transform_divisions=False)
     df2 = df.assign(_partitions=partitions)
+    df2._meta.index.name = df._meta.index.name
     df3 = rearrange_by_column(df2, '_partitions', npartitions=npartitions,
                               max_branch=max_branch, shuffle=shuffle,
                               compute=compute)
@@ -534,5 +537,8 @@ def compute_divisions(df, **kwargs):
         raise ValueError("Partitions must be sorted ascending with the index",
                          mins, maxes)
 
+    if any(a >= b for a, b in zip(maxes[:1], mins[1:])):
+        warnings.warn("Partition indices have overlap.")
+
     divisions = tuple(mins) + (list(maxes)[-1],)
     return divisions
