@@ -582,7 +582,7 @@ def test_set_index_raises_error_on_bad_input():
 
 def test_set_index_sorted_true():
     df = pd.DataFrame({'x': [1, 2, 3, 4],
-                       'y': [10, 20, 30, 40],
+                       'y': [10, 20, 20, 40],
                        'z': [4, 3, 2, 1]})
     a = dd.from_pandas(df, 2, sort=False)
     assert not a.known_divisions
@@ -602,6 +602,9 @@ def test_set_index_sorted_true():
     with pytest.raises(ValueError):
         a.set_index(a.z, sorted=True)
 
+    with pytest.warns(UserWarning):
+        a.set_index(a.y, sorted=True)
+
 
 def test_set_index_sorted_single_partition():
     df = pd.DataFrame({'x': [1, 2, 3, 4], 'y': [1, 0, 1, 0]})
@@ -670,7 +673,7 @@ def test_set_index_on_empty():
 def test_compute_divisions():
     from dask.dataframe.shuffle import compute_divisions
     df = pd.DataFrame({'x': [1, 2, 3, 4],
-                       'y': [10, 20, 30, 40],
+                       'y': [10, 20, 20, 40],
                        'z': [4, 3, 2, 1]},
                       index=[1, 3, 10, 20])
     a = dd.from_pandas(df, 2, sort=False)
@@ -683,6 +686,11 @@ def test_compute_divisions():
     assert_eq(a, b, check_divisions=False)
     assert b.known_divisions
 
+    c = dd.from_pandas(df.set_index('y'), 2, sort=False)
+    # Partitions overlap warning
+    with pytest.warns(UserWarning):
+        compute_divisions(c)
+
 
 def test_temporary_directory(tmpdir):
     df = pd.DataFrame({'x': np.random.random(100),
