@@ -1,5 +1,7 @@
 from __future__ import absolute_import, division, print_function
 
+import math
+import numbers
 import re
 import textwrap
 from distutils.version import LooseVersion
@@ -386,17 +388,26 @@ def _nonempty_index(idx):
         # and https://github.com/pandas-dev/pandas/issues/16515
         # This doesn't mean `_meta_nonempty` should ever rely on
         # `self.monotonic_increasing` or `self.monotonic_decreasing`
-        data = [start, '1970-01-02'] if idx.freq is None else None
-        return pd.DatetimeIndex(data, start=start, periods=2, freq=idx.freq,
-                                tz=idx.tz, name=idx.name)
+        try:
+            return pd.date_range(start=start, periods=2, freq=idx.freq,
+                                 tz=idx.tz, name=idx.name)
+        except ValueError:  # older pandas versions
+            data = [start, '1970-01-02'] if idx.freq is None else None
+            return pd.DatetimeIndex(data, start=start, periods=2, freq=idx.freq,
+                                    tz=idx.tz, name=idx.name)
     elif typ is pd.PeriodIndex:
         return pd.period_range(start='1970-01-01', periods=2, freq=idx.freq,
                                name=idx.name)
     elif typ is pd.TimedeltaIndex:
         start = np.timedelta64(1, 'D')
-        data = [start, start + 1] if idx.freq is None else None
-        return pd.TimedeltaIndex(data, start=start, periods=2, freq=idx.freq,
-                                 name=idx.name)
+        try:
+            return pd.timedelta_range(start=start, periods=2, freq=idx.freq,
+                                      name=idx.name)
+        except ValueError:  # older pandas versions
+            start = np.timedelta64(1, 'D')
+            data = [start, start + 1] if idx.freq is None else None
+            return pd.TimedeltaIndex(data, start=start, periods=2,
+                                     freq=idx.freq, name=idx.name)
     elif typ is pd.CategoricalIndex:
         if len(idx.categories) == 0:
             data = pd.Categorical(_nonempty_index(idx.categories),
@@ -407,8 +418,12 @@ def _nonempty_index(idx):
         return pd.CategoricalIndex(data, name=idx.name)
     elif typ is pd.MultiIndex:
         levels = [_nonempty_index(l) for l in idx.levels]
-        labels = [[0, 0] for i in idx.levels]
-        return pd.MultiIndex(levels=levels, labels=labels, names=idx.names)
+        codes = [[0, 0] for i in idx.levels]
+        try:
+            return pd.MultiIndex(levels=levels, codes=codes, names=idx.names)
+        except TypeError:  # older pandas versions
+            return pd.MultiIndex(levels=levels, labels=codes, names=idx.names)
+
     raise TypeError("Don't know how to handle index of "
                     "type {0}".format(type(idx).__name__))
 
@@ -497,18 +512,27 @@ def _nonempty_series(s, idx=None):
 
 def is_dataframe_like(df):
     """ Looks like a Pandas DataFrame """
-    return set(dir(df)) > {'dtypes', 'columns', 'groupby', 'head'} and not isinstance(df, type)
+    typ = type(df)
+    return (all(hasattr(typ, name)
+                for name in ('groupby', 'head', 'merge', 'mean')) and
+            all(hasattr(df, name) for name in ('dtypes',)) and not
+            any(hasattr(typ, name)
+                for name in ('value_counts', 'dtype')))
 
 
 def is_series_like(s):
     """ Looks like a Pandas Series """
-    return set(dir(s)) > {'name', 'dtype', 'groupby', 'head'} and not isinstance(s, type)
+    typ = type(s)
+    return (all(hasattr(typ, name) for name in ('groupby', 'head', 'mean')) and
+            all(hasattr(s, name) for name in ('dtype', 'name')) and
+            'index' not in typ.__name__.lower())
 
 
 def is_index_like(s):
     """ Looks like a Pandas Index """
-    attrs = set(dir(s))
-    return attrs > {'name', 'dtype'} and 'head' not in attrs and not isinstance(s, type)
+    typ = type(s)
+    return (all(hasattr(s, name) for name in ('name', 'dtype'))
+            and 'index' in typ.__name__.lower())
 
 
 def check_meta(x, meta, funcname=None, numeric_equal=True):
@@ -728,9 +752,7 @@ def assert_dask_graph(dask, label):
 def assert_divisions(ddf):
     if not hasattr(ddf, 'divisions'):
         return
-    if not hasattr(ddf, 'index'):
-        return
-    if not ddf.known_divisions:
+    if not getattr(ddf, 'known_divisions', False):
         return
 
     def index(x):
@@ -803,3 +825,40 @@ def assert_max_deps(x, n, eq=True):
         assert max(map(len, dependencies.values())) == n
     else:
         assert max(map(len, dependencies.values())) <= n
+
+
+def valid_divisions(divisions):
+    """ Are the provided divisions valid?
+
+    Examples
+    --------
+    >>> valid_divisions([1, 2, 3])
+    True
+    >>> valid_divisions([3, 2, 1])
+    False
+    >>> valid_divisions([1, 1, 1])
+    False
+    >>> valid_divisions([0, 1, 1])
+    True
+    >>> valid_divisions(123)
+    False
+    >>> valid_divisions([0, float('nan'), 1])
+    False
+    """
+    if not isinstance(divisions, (tuple, list)):
+        return False
+
+    for i, x in enumerate(divisions[:-2]):
+        if x >= divisions[i + 1]:
+            return False
+        if isinstance(x, numbers.Number) and math.isnan(x):
+            return False
+
+    for x in divisions[-2:]:
+        if isinstance(x, numbers.Number) and math.isnan(x):
+            return False
+
+    if divisions[-2] > divisions[-1]:
+        return False
+
+    return True
