@@ -107,31 +107,16 @@ class GetFunctionTestMixin(object):
         assert self.get(d, 'z') == 4
 
     def test_get_stack_limit(self):
-        d = dict(('x%d' % (i + 1), (inc, 'x%d' % i)) for i in range(10000))
+        d = {'x%d' % (i + 1): (inc, 'x%d' % i) for i in range(10000)}
         d['x0'] = 0
         assert self.get(d, 'x10000') == 10000
-        # introduce cycle
-        d['x5000'] = (inc, 'x5001')
 
-        try:
-            self.get(d, 'x10000')
-        except (RuntimeError, ValueError) as e:
-            if isinstance(e, RuntimeError):
-                assert str(e) == 'Cycle detected in Dask: x5001->x5000->x5001'
-            elif isinstance(e, ValueError):
-                assert str(e).startswith('Found no accessible jobs in dask')
-        else:
-            msg = 'dask with infinite cycle should have raised an exception.'
-            assert False, msg
+    def test_with_HighLevelGraph(self):
+        from .highlevelgraph import HighLevelGraph
 
-        assert self.get(d, 'x4999') == 4999
-
-    def test_with_sharedict(self):
-        from .sharedict import ShareDict
-
-        dsk = ShareDict()
-        dsk.update({'x': 1,
-                    'y': (inc, 'x')})
-        dsk.update({'z': (add, (inc, 'x'), 'y')})
-
-        assert self.get(dsk, 'z') == 4
+        layers = {'a': {'x': 1,
+                        'y': (inc, 'x')},
+                  'b': {'z': (add, (inc, 'x'), 'y')}}
+        dependencies = {'a': (), 'b': {'a'}}
+        graph = HighLevelGraph(layers, dependencies)
+        assert self.get(graph, 'z') == 4
